all.Enoss<-function(){
     cat("\n")
     note_for_Eno_input()
     cat("\n")
     note_for_close_window()
     EnoSSpar<-data.frame(parameter=c("Gender","TBW (kg)","Scr (mg/dL)","D (IU)","tau (hr)","Amax (IU/mL)"),value=c(0))
     EnoSSpar<-edit(EnoSSpar)
##     EnoSSpar<-ycheck(EnoSSpar)
     cat("\n")
     Eno.ss(EnoSSpar[6,2],EnoSSpar[5,2],EnoSSpar[4,2],EnoSSpar[2,2],EnoSSpar[1,2],EnoSSpar[3,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Eno_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Enocpr(EnoSSpar[4,2],EnoSSpar[5,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Amaxss_pr (IU/mL) ")
     show(coutput)
     cat("\n") 
     Eno.more()
}